@@ -151,3 +151,20 @@ void DBusAdaptor::choose()
   if( _sti )
     _sti->choose();
 }
+
+/** chooseRecentFile - Opens a recently-edited file using a dialog.
+  */
+void DBusAdaptor::chooseRecentFile()
+{
+  if( _sti )
+    _sti->chooseRecentFile();
+}
+
+/** chooseQuickpostTemplate - Does a Quickpost by choosing a template from a dialog.
+  */
+void DBusAdaptor::chooseQuickpostTemplate()
+{
+  if( _sti )
+    _sti->chooseQuickpostTemplate();
+}
+
