@@ -24,9 +24,20 @@
 #include <QtGui>
 #include <QtXml>
 
+#if QT_VERSION >= 0x050000
+#include <QtWidgets>
+#endif
+
 #include "EditingWindow.h"
+#include "SuperMenu.h"
 #include "XmlRpcHandler.h"
 
+typedef enum _WWDN {
+  NoActivity,
+  GettingID,
+  GettingContent
+} PostIDActivity;
+
 void EditingWindow::blogger_getUsersBlogs( QByteArray response )
 {
   QXmlInputSource xis;
@@ -54,7 +65,7 @@ void EditingWindow::blogger_getUsersBlogs( QByteArray response )
   int i = blogNodeList.count();
   QString fstring = handler.faultString();
   if( !fstring.isEmpty() ) {
-    statusBar()->showMessage( tr( "Could not connect - check account details & password" ), 2000 );
+    statusWidget->showMessage( tr( "Could not connect - check account details & password" ), 2000 );
     addToConsole( QString( "%1\n" ).arg( fstring ) );
     cw.cbBlogSelector->setEnabled( false );
     cw.chNoCats->setEnabled( false );
@@ -65,7 +76,7 @@ void EditingWindow::blogger_getUsersBlogs( QByteArray response )
   }
   else {
     if( !i ) {
-      statusBar()->showMessage( tr( "No blogs found" ), 2000 );
+      statusWidget->showMessage( tr( "No blogs found" ), 2000 );
     }
     else {
       currentAccountElement.removeChild( currentAccountElement.firstChildElement( "blogs" ) );
@@ -81,7 +92,7 @@ void EditingWindow::blogger_getUsersBlogs( QByteArray response )
           //qDebug() << "saved";
         }
         else
-          statusBar()->showMessage( tr( "Could not write to accounts file (error %1)" ).arg( (int)domOut.error() ), 2000 );
+          statusWidget->showMessage( tr( "Could not write to accounts file (error %1)" ).arg( (int)domOut.error() ), 2000 );
       }
 
       for( int a = 0; a < i; a++ ) {
@@ -128,7 +139,7 @@ void EditingWindow::metaWeblog_newPost( QByteArray response )
 
   addToConsole( QString( response ) );
   if( response.contains( "<fault>" ) ) {
-    statusBar()->showMessage( tr( "The submission returned a fault - see console." ), 2000 );
+    statusWidget->showMessage( tr( "The submission returned a fault - see console." ), 2000 );
     if( QApplication::overrideCursor() )
       QApplication::restoreOverrideCursor();
     QTimer::singleShot( 1000, this, SLOT( hideProgressBar() ) );
@@ -137,9 +148,11 @@ void EditingWindow::metaWeblog_newPost( QByteArray response )
     QString parsedData( response );
     entryNumber = parsedData.section( "<string>", 1, 1 )
       .section( "</string>", -2, -2 );
-    if( !cw.chNoCats->isChecked() )
-      connect( this, SIGNAL( httpBusinessFinished() ),
-               this, SLOT( setPostCategories() ) );
+    if( !useWordpressAPI ) {
+      if( !cw.chNoCats->isChecked() )
+        connect( this, SIGNAL( httpBusinessFinished() ),
+                 this, SLOT( setPostCategories() ) );
+    }
 
     if( !entryEverSaved ) {
       if( postAsSave && cleanSave ) {
@@ -148,10 +161,10 @@ void EditingWindow::metaWeblog_newPost( QByteArray response )
         setDirtySignals( true );
       }
     }
+  entryBlogged = true;
   }
 
   addToConsole( QString( "Entry number: %1\n" ).arg( entryNumber ) );
-  entryBlogged = true;
 }
 
 
@@ -160,12 +173,13 @@ void EditingWindow::metaWeblog_editPost( QByteArray response )
   addToConsole( QString( response ) );
 
   if( response.contains( "<fault>" ) ) {
-    statusBar()->showMessage( tr( "The submission returned a fault - see console." ), 2000 );
+    statusWidget->showMessage( tr( "The submission returned a fault - see console." ), 2000 );
     QTimer::singleShot( 1000, this, SLOT( hideProgressBar() ) );
   }
   else {
-    connect( this, SIGNAL( httpBusinessFinished() ),
-             this, SLOT( setPostCategories() ) );
+    if( !useWordpressAPI )
+      connect( this, SIGNAL( httpBusinessFinished() ),
+               this, SLOT( setPostCategories() ) );
     if( !entryEverSaved ) {
       if( postAsSave && cleanSave ) {
         setWindowModified( false );
@@ -198,14 +212,15 @@ void EditingWindow::metaWeblog_newMediaObject( QByteArray response )
       cw.cbPageSelector->setCurrentIndex( 0 );
       cw.stackedWidget->setCurrentIndex( 0 );
       cw.copyURLWidget->show();
-      ui.actionCopy_upload_location->setVisible( true );
-      statusBar()->showMessage( tr( "Your file is here: %1" ).arg( remoteFileLocation ), 2000 );
+      if( superMenu )
+        superMenu->copyULAction->setVisible( true );
+      statusWidget->showMessage( tr( "Your file is here: %1" ).arg( remoteFileLocation ), 2000 );
     }
     else
-      statusBar()->showMessage( tr( "The upload returned a fault." ), 2000 );
+      statusWidget->showMessage( tr( "The upload returned a fault." ), 2000 );
   }
   else {
-    statusBar()->showMessage( tr( "The upload returned a fault." ), 2000 );
+    statusWidget->showMessage( tr( "The upload returned a fault." ), 2000 );
   }
 #ifndef NO_DEBUG_OUTPUT
   // qDebug() << "Finished handling response";
@@ -221,9 +236,9 @@ void EditingWindow::mt_publishPost( QByteArray response )
   addToConsole( QString( response ) );
 
   if( response.contains( "<fault>" ) )
-    statusBar()->showMessage( tr( "An error occurred during rebuilding." ), 2000 );
+    statusWidget->showMessage( tr( "An error occurred during rebuilding." ), 2000 );
   else
-    statusBar()->showMessage( tr( "The post was published successfully." ), 2000 );
+    statusWidget->showMessage( tr( "The post was published successfully." ), 2000 );
 
   if( QApplication::overrideCursor() != 0 )
     QApplication::restoreOverrideCursor();
@@ -236,8 +251,9 @@ void EditingWindow::mt_getCategoryList( QByteArray response )
   XmlRpcHandler handler( currentHttpBusiness );
   QDomDocumentFragment importedCategoryList;
   QDomElement newCategoriesElement, currentCategory, currentID, currentName;
-  QString xmlRpcFaultString;
+  QString xmlRpcFaultString, ccID;
   QStringList catList;
+  int uncategorized = 0, itval = 0;
 
   cw.lwOtherCats->reset();
 
@@ -273,11 +289,11 @@ void EditingWindow::mt_getCategoryList( QByteArray response )
     qSort( catList.begin(), catList.end(), EditingWindow::caseInsensitiveLessThan );
 
   if( xfault ) {
-    statusBar()->showMessage( tr( "Could not connect; check account details & password" ), 2000 );
+    statusWidget->showMessage( tr( "Could not connect; check account details & password" ), 2000 );
   }
   else {
     if( !i ) {
-      statusBar()->showMessage( tr( "There are no categories." ) );
+      statusWidget->showMessage( tr( "There are no categories." ) );
       cw.chNoCats->setEnabled( false );
       cw.cbMainCat->setEnabled( false );
       cw.lwOtherCats->setEnabled( false );
@@ -288,9 +304,12 @@ void EditingWindow::mt_getCategoryList( QByteArray response )
       cw.cbMainCat->clear();
       cw.lwOtherCats->clear();
       for( it = catList.begin(); it != catList.end(); ++it ) {
+        ccID = it->section( " ##ID:", 1, 1 );
         cw.cbMainCat->addItem( it->section( " ##ID:", 0, 0 ),
-                               QVariant( it->section( " ##ID:", 1, 1 ) ) );
+                               QVariant( ccID ) );
         cw.lwOtherCats->addItem( it->section( " ##ID:", 0, 0 ) );
+        if( ccID == "1" )
+          uncategorized = itval;
         currentCategory = accountsDom.createElement( "category" );
         currentID = accountsDom.createElement( "categoryId" );
         currentID.appendChild( accountsDom.createTextNode( it->section( " ##ID:", 1 ) ) );
@@ -299,7 +318,10 @@ void EditingWindow::mt_getCategoryList( QByteArray response )
         currentCategory.appendChild( currentID );
         currentCategory.appendChild( currentName );
         newCategoriesElement.appendChild( currentCategory );
+        itval++;
       }
+      if( uncategorized )
+        cw.cbMainCat->setCurrentIndex( uncategorized );
       if( currentBlogElement.firstChildElement( "categories" ).isNull() )
         currentBlogElement.appendChild( newCategoriesElement );
       else
@@ -308,6 +330,7 @@ void EditingWindow::mt_getCategoryList( QByteArray response )
       cw.chNoCats->setEnabled( true );
       cw.cbMainCat->setEnabled( true );
       cw.lwOtherCats->setEnabled( true );
+      handleEnableCategories();
       if( !noAutoSave ) {
         QFile domOut( PROPERSEPS( QString( "%1/qtmaccounts2.xml" ).arg( localStorageDirectory ) ) );
         if( domOut.open( QIODevice::WriteOnly ) ) {
@@ -317,7 +340,7 @@ void EditingWindow::mt_getCategoryList( QByteArray response )
           //qDebug() << "saved";
         }
         else
-          statusBar()->showMessage( tr( "Could not write to accounts file (error %1)" ).arg( (int)domOut.error() ), 2000 );
+          statusWidget->showMessage( tr( "Could not write to accounts file (error %1)" ).arg( (int)domOut.error() ), 2000 );
       }
     }
   }
@@ -331,6 +354,31 @@ void EditingWindow::mt_getCategoryList( QByteArray response )
     QApplication::restoreOverrideCursor();
 }
 
+void EditingWindow::mt_setPostCategories( QByteArray response )
+{
+  disconnect( this, SIGNAL( httpBusinessFinished() ), 0, 0 );
+
+  QXmlInputSource xis;
+  QXmlSimpleReader reader;
+  XmlRpcHandler handler( currentHttpBusiness );
+  QList<QString> parsedData;
+  QString rdata( response );
+
+  if( rdata.contains( "<fault>" ) ) {
+    statusWidget->showMessage( tr( "Categories not set successfully; see console." ), 2000 );
+    QTimer::singleShot( 1000, this, SLOT( hideProgressBar() ) );
+  }
+  else {
+    statusWidget->showMessage( tr( "Categories set successfully." ), 2000 );
+
+    if( ( location.contains( "mt-xmlrpc.cgi" ) || useWordpressAPI ) && cw.cbStatus->currentIndex() == 1 )
+      connect( this, SIGNAL( httpBusinessFinished() ),
+               this, SLOT( publishPost() ) );
+  }
+  addToConsole( rdata );
+  QApplication::restoreOverrideCursor();
+}
+
 void EditingWindow::wp_getTags( QByteArray response )
 {
   disconnect( this, SIGNAL( httpBusinessFinished() ), 0, 0 );
@@ -415,7 +463,7 @@ void EditingWindow::wp_getTags( QByteArray response )
 
   }
   else
-    statusBar()->showMessage( tr( "This blog has no tags." ), 2000 );
+    statusWidget->showMessage( tr( "This blog has no tags." ), 2000 );
 
   addToConsole( QString( response ) );
 
@@ -423,6 +471,112 @@ void EditingWindow::wp_getTags( QByteArray response )
     QApplication::restoreOverrideCursor();
 }
 
+void EditingWindow::wp_getPosts_ID_Only( QByteArray response )
+{
+  disconnect( this, SIGNAL( httpBusinessFinished() ), 0, 0 );
+  addToConsole( response );
+
+  QString responseString( response );
+  QStringList structs = responseString.split( QRegExp( "</?struct>" ) );
+
+  QString post_id, post_content, this_post_ID, this_post_content;
+
+  Q_FOREACH( QString this_struct, structs ) {
+    if( this_struct.startsWith( "</value>" ) )
+      continue;
+
+    this_post_ID = this_struct.section( "<name>post_id</name><value><string>", 1, 1 )
+      .section( "</string>", 0, 0 );
+    this_post_content = this_struct.section( "<name>post_content</name><value><string>", 1, 1 )
+      .section( "</string>", 0, 0 );
+    qDebug() << "Post ID:" << this_post_ID;
+    qDebug() << "Content:" << this_post_content.left( 50 ) << "..." << this_post_content.right( 50 );
+
+    if( this_post_content.contains( entryHash ) ) {
+      entryNumber = this_post_ID;
+      statusWidget->showMessage( tr( "Post published successfully." ), 2000 );
+      cw.progressBar->setValue( cw.progressBar->value() + 1 );
+      if( QApplication::overrideCursor() != 0 )
+        QApplication::restoreOverrideCursor();
+      if( !entryEverSaved ) {
+        if( postAsSave && cleanSave ) {
+          setWindowModified( false );
+          dirtyIndicator->hide();
+          setDirtySignals( true );
+        }
+      }
+      entryBlogged = true;
+
+      return;
+    }
+  }
+/*
+  QXmlStreamReader::TokenType tokenType;
+  QString currentElementName, currentText, postID, postContent;
+
+  QXmlStreamReader streamReader( response );
+  PostIDActivity currentActivity = NoActivity;
+  while( !streamReader.atEnd() ) {
+    tokenType = streamReader.readNext();
+    switch( tokenType ) {
+      case QXmlStreamReader::StartElement:
+        currentElementName = streamReader.name().toString();
+        if( currentElementName == "struct" ) {
+          postID = "";
+          postContent = "";
+        }
+        break;
+      case QXmlStreamReader::Characters:
+        currentText = streamReader.text().toString();
+        if( currentElementName == "name" ) {
+          if( currentText == "post_id" ) {
+            currentActivity = GettingID;
+            break;
+          }
+          if( currentText == "post_content" ) {
+            currentActivity = GettingContent;
+            break;
+          }
+        }
+        if( currentElementName == "string" && currentActivity == GettingID ) {
+          postID = currentText;
+          currentActivity = NoActivity;
+          break;
+        }
+        if( currentElementName == "string" && currentActivity == GettingContent ) {
+          postContent = currentText;
+          currentActivity = NoActivity;
+          break;
+        }
+        break;
+      case QXmlStreamReader::EndElement:
+        currentElementName = streamReader.name().toString();
+        if( currentElementName == "struct" ) {
+          if( postContent.contains( entryHash ) ) {
+            entryNumber = postID;
+            cw.progressBar->setValue( cw.progressBar->value() + 1 );
+            if( QApplication::overrideCursor() != 0 )
+              QApplication::restoreOverrideCursor();
+            if( !entryEverSaved ) {
+              if( postAsSave && cleanSave ) {
+                setWindowModified( false );
+                dirtyIndicator->hide();
+                setDirtySignals( true );
+              }
+            }
+            
+            return;
+          }
+        }
+    }
+
+  }*/
+  statusWidget->showMessage( tr( "Could not get entry ID, but entry may have posted." ), 2000 );
+
+  if( QApplication::overrideCursor() != 0 )
+    QApplication::restoreOverrideCursor();
+}
+
 void EditingWindow::wp_newCategory( QByteArray response )
 {
   disconnect( this, SIGNAL( httpBusinessFinished() ), 0, 0 );
@@ -438,10 +592,20 @@ void EditingWindow::wp_newCategory( QByteArray response )
              this, SLOT( refreshCategories() ) );
   }
   else
-    statusBar()->showMessage( tr( "The request caused a fault; see console." ), 2000 );
+    statusWidget->showMessage( tr( "The request caused a fault; see console." ), 2000 );
 
   addToConsole( responseString );
 
   QApplication::restoreOverrideCursor();
 }
 
+void EditingWindow::wp_newPost( QByteArray response )
+{
+  metaWeblog_newPost( response );
+}
+
+void EditingWindow::wp_editPost( QByteArray response )
+{
+  metaWeblog_editPost( response );
+}
+
