@@ -32,8 +32,8 @@ Q_OBJECT
 
   void setIdentifier( int );
   void setPostTemplate( QString );
-  int identifier(); 
-  QString postTemplate();
+  int identifier() { return _identifier; }
+  QString postTemplate() { return _postTemplate; }
 
  signals:
   void quickpostRequested( int, QString );
