@@ -27,7 +27,7 @@
 
 #ifdef USE_SYSTRAYICON
 
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 #include <QSystemTrayIcon>
 //#include "macFunctions.h"
 #endif
@@ -42,7 +42,7 @@
 #include <QCoreApplication>
 #include <QClipboard>
 #include <QUrl>
-#include <QHttpRequestHeader>
+//#include <QHttpRequestHeader>
 #include <QList>
 #include <QFile>
 #include <QTextStream>
@@ -69,10 +69,18 @@
 
 //#include "ui_QuickpostTemplateForm.h"
 
+#if QT_VERSION >= 0x050000
+#ifdef Q_OS_UNIX
+#if !defined Q_OS_MAC && !defined Q_OS_CYGWIN
+#define Q_WS_X11
+#endif
+#endif
+#endif
+
 #ifdef Q_WS_X11
 #include "susesystray.xpm"
 #else
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN32
 #include "winsystray.xpm"
 #include "winsystray_busy.xpm"
 #endif
@@ -118,7 +126,7 @@
 
   qtm = qobject_cast<Application *>( qApp );
 
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
   switch( doubleClickFunction ) {
     case 0:
       setToolTip( tr( "QTM - Double click for \nnew entry" ) ); break;
@@ -155,8 +163,15 @@
            this, SLOT( configureQuickpostTemplates() ) );
   configureTemplates->setObjectName( "QTM Configure Templates" );
   setupQuickpostTemplates();
-  menu->addAction( newWindowAtStartup );
-#ifndef Q_WS_MAC
+
+#if (!defined Q_OS_MAC) || QT_VERSION <= 0x050000
+//#ifndef Q_OS_MAC              // Always a new window at startup when
+//#if QT_VERSION <= 0x050000   // using Qt 5 on a Mac
+  if( !isUnityThere )
+    menu->addAction( newWindowAtStartup );
+#endif
+
+#ifndef Q_OS_MAC
   menu->addSeparator();
 #endif
 #ifndef SUPERMENU
@@ -164,32 +179,34 @@
 #endif
   // quitAction->setMenuRole( QAction::QuitRole );
   menu->setObjectName( "iconMenu" );
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
+#if QT_VERSION >= 0x050000 // Qt versions 5.0 and 5.1 have neither of these.
+  menu->setAsDockMenu();
+#else
   qt_mac_set_dock_menu( menu );
+#endif // QT_VERSION
 #else
   setContextMenu( menu );
 #endif
   //show();
 
+  qtm->setupRecentFiles();
   recentFilesMenu = new QMenu;
   noRecentFilesAction = new QAction( tr( "No recent files" ), this );
   noRecentFilesAction->setVisible( true );
   noRecentFilesAction->setEnabled( false );
-  recentFilesMenu->addAction( noRecentFilesAction );
-  openRecent->setMenu( recentFilesMenu );
   for( int i = 0; i < 10; ++i ) {
     recentFileActions[i] = new QAction( this );
-    recentFilesMenu->addAction( recentFileActions[i] );
     connect( recentFileActions[i], SIGNAL( triggered() ),
              this, SLOT( openRecentFile() ) );
   }
   recentFiles = qtm->recentFiles();
-  //  // qDebug() << recentFiles.count() << " recent files";
   updateRecentFileMenu();
+  openRecent->setMenu( recentFilesMenu );
   connect( qtm, SIGNAL( recentFilesUpdated( QList<Application::recentFile> ) ),
            this, SLOT( setRecentFiles( QList<Application::recentFile> ) ) );
 
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
   connect( this, SIGNAL( activated( QSystemTrayIcon::ActivationReason ) ),
            this, SLOT( iconActivated( QSystemTrayIcon::ActivationReason ) ) );
 #endif
@@ -197,17 +214,16 @@
   if( handleArguments() )
     noNewWindow = true;
 
+#ifndef Q_OS_MAC
   if( newWindow && !noNewWindow ) {
     EditingWindow *c = new EditingWindow;
     c->setSTI( this );
     c->setWindowTitle( tr( "QTM - new entry [*]" ) );
-#ifdef Q_WS_MAC
-    //setNoStatusBar( c );
-#endif
     c->show();
     c->activateWindow();
   }
-  //cbtextIsURL = Untested;
+#endif
+  
   netmgr = new QNetworkAccessManager;
   httpBusy = false;
   templateQPActive = false;
@@ -233,7 +249,7 @@ bool SysTrayIcon::handleArguments()
       qDebug() << "Opening:" << args.at( i );
       if( c->load( args.at( i ), true ) ) {
         c->setSTI( this );
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 	//setNoStatusBar( c );
 #endif
         c->show();
@@ -270,6 +286,7 @@ void SysTrayIcon::updateRecentFileMenu()
 {
   QString text, t;
   int j;
+  // qDebug() << "Recent files:" << recentFiles.count();
   QMutableListIterator<Application::recentFile> i( recentFiles );
 
   while( i.hasNext() ) {
@@ -277,11 +294,18 @@ void SysTrayIcon::updateRecentFileMenu()
       i.remove();
   }
 
+  recentFilesMenu->clear();
+
   for( j = 0; j < 10; ++j ) {
     if( j < recentFiles.count() ) {
       t = recentFiles.value( j ).title.section( ' ', 0, 5 );
       if( t != recentFiles.value( j ).title )
         t.append( tr( " ..." ) );
+#ifdef Q_OS_MAC
+      text = recentFiles.value( j ).title.isEmpty() ?
+        recentFiles.value( j ).filename.section( "/", -1, -1 )
+        :t.replace( '&', "&&" );
+#else
       if( j == 9 )
         text = tr( "1&0 %1" )
           .arg( recentFiles.value( j ).title.isEmpty() ?
@@ -293,15 +317,16 @@ void SysTrayIcon::updateRecentFileMenu()
           .arg( recentFiles.value( j ).title.isEmpty() ?
                 recentFiles.value( j ).filename.section( "/", -1, -1 )
                 : t.replace( '&', "&&" ) );
+#endif
       recentFileActions[j]->setText( text );
       recentFileActions[j]->setData( recentFiles.value( j ).filename );
-      recentFileActions[j]->setVisible( true );
-      noRecentFilesAction->setVisible( false );
+      recentFilesMenu->addAction( recentFileActions[j] );
+      recentFilesMenu->removeAction( noRecentFilesAction );
     }
     else {
-      recentFileActions[j]->setVisible( false );
+      // recentFileActions[j]->setVisible( false );
       if( !recentFiles.count() )
-        noRecentFilesAction->setVisible( true );
+        recentFilesMenu->addAction( noRecentFilesAction );
     }
   }
 }
@@ -316,7 +341,7 @@ void SysTrayIcon::setDoubleClickFunction( int func )
 {
   doubleClickFunction = func;
 
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
   switch( doubleClickFunction ) {
     case 0:
       setToolTip( tr( "QTM - Double click for \nnew entry" ) ); break;
@@ -366,10 +391,16 @@ void SysTrayIcon::newDoc()
 {
   EditingWindow *c = new EditingWindow;
   c->setSTI( this );
+  c->setWindowTitle( QObject::tr( "QTM - new entry [*]" ) );
   c->setPostClean();
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
   //setNoStatusBar( c );
 #endif
+  EditingWindow *activeWidget = qtm->currentEditingWindow();
+  qDebug() << "got active widget";
+  if( activeWidget )
+    EditingWindow::positionWidget( c, activeWidget );
+  qDebug() << "positioned widget";
   c->show();
   c->activateWindow();
   QApplication::alert( c );
@@ -406,7 +437,7 @@ void SysTrayIcon::choose( QString fname )
   if( !fn.isEmpty() ) {
     EditingWindow *e = new EditingWindow;
     if( !e->load( fn, true ) ) {
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
       QMessageBox::warning( 0, "QTM",
                             tr( "Could not load the file you specified." ),
                             QMessageBox::Cancel, QMessageBox::NoButton );
@@ -419,7 +450,7 @@ void SysTrayIcon::choose( QString fname )
     } else {
       e->setSTI( this );
       qtm->addRecentFile( e->postTitle(), fn );
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
       //setNoStatusBar( e );
 #endif
       e->show();
@@ -429,9 +460,56 @@ void SysTrayIcon::choose( QString fname )
   }
 }
 
+void SysTrayIcon::chooseRecentFile()
+{
+#ifdef UNITY_LAUNCHER
+  int i, j;
+  QString fileToOpen;
+  QList<QListWidgetItem *> recentFilesForDialog;
+  QListWidgetItem *thisRecentFile;
+
+  QDialog chooser;
+  Ui::ListDialogBase ldui;
+  ldui.setupUi( &chooser );
+
+  chooser.setAttribute( Qt::WA_DeleteOnClose, false );
+  chooser.setWindowTitle( tr( "Choose recent file" ) );
+  ldui.mainLabel->setText( tr( "Recent files:" ) );
+
+  // Load the recent files into the list widget
+  recentFiles = qtm->recentFiles();
+  j = (recentFiles.count() >= 10) ? 10 : recentFiles.count();
+  for( i = 0; i < j; i++ ) {
+    thisRecentFile = new QListWidgetItem( recentFiles.at( i ).title );
+    thisRecentFile->setData( 32, recentFiles.at( i ).filename );
+    ldui.lwFileTemplateList->addItem( thisRecentFile );
+  }
+
+  connect( ldui.lwFileTemplateList, SIGNAL( itemDoubleClicked( QListWidgetItem * ) ),
+           this, SLOT( openRecentFileFromDialog( QListWidgetItem * ) ) );
+  // Dialog must only accept if OK is clicked, as double-click is handled by
+  // the above slot.
+  connect( ldui.lwFileTemplateList, SIGNAL( itemDoubleClicked( QListWidgetItem * ) ),
+           &chooser, SLOT( reject() ) );
+
+  if( chooser.exec() ) {
+    fileToOpen = ldui.lwFileTemplateList->currentItem()->data( 32 ).toString();
+    choose( fileToOpen );
+  }
+#endif
+}
+
+void SysTrayIcon::openRecentFileFromDialog( QListWidgetItem *item )
+{
+#ifdef UNITY_LAUNCHER
+  QString fileToOpen = item->data( 32 ).toString();
+  choose( fileToOpen );
+#endif
+}
+
 void SysTrayIcon::iconActivated( QSystemTrayIcon::ActivationReason ar )
 {
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
   if( ar == QSystemTrayIcon::DoubleClick )
     switch( doubleClickFunction ) {
       case 0: newDoc(); break;
@@ -454,7 +532,7 @@ void SysTrayIcon::quickpost( QClipboard::Mode mode )
   cbtext = QApplication::clipboard()->text( mode );
 
   if( cbtext == "" ) {
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     QMessageBox::warning( 0, tr( "No selection! - QTM" ),
                           tr( "No web location specified to blog about." ),
                           QMessageBox::Cancel );
@@ -473,7 +551,7 @@ void SysTrayIcon::quickpost( QClipboard::Mode mode )
 
       // If it's not obviously an URL.
       if( cbtext.startsWith( "https" ) ) {
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
           showMessage( tr( "Error" ), tr( "This version of QTM does not support HTTPS." ) );
 #else
           QMessageBox::information( 0, tr( "Quickpost Error" ),
@@ -488,7 +566,7 @@ void SysTrayIcon::quickpost( QClipboard::Mode mode )
           doQP( "" );
         }
         else {
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
           QMessageBox::warning( 0, tr( "Invalid web location" ),
                                 tr( "Quick Post requires valid web location." ),
                                 QMessageBox::Cancel );
@@ -549,7 +627,7 @@ void SysTrayIcon::quickpost( QClipboard::Mode mode )
             abortAction->setEnabled( true );
             httpBusy = true;
             templateQPActive = false;
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN32
             setIcon( QIcon( QPixmap( sysTrayIcon_busy_xpm ) ) );
 #endif
             connect( netmgr, SIGNAL( finished( QNetworkReply * ) ),
@@ -572,7 +650,7 @@ void SysTrayIcon::quickpostFromTemplate( int id, QString templateString, QString
     cbtext = t;
 
   if( cbtext.startsWith( "https://" ) ) {
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
       showMessage( tr( "Error" ),
                    tr( "This version of QTM does not support HTTPS." ) );
 #else
@@ -582,7 +660,7 @@ void SysTrayIcon::quickpostFromTemplate( int id, QString templateString, QString
   }
 
   if( !QUrl( cbtext, QUrl::StrictMode ).isValid() ) {
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     QMessageBox::warning( 0, tr( "No selection!" ),
                           tr( "The selection is not a web location, or is invalid." ),
                           QMessageBox::Cancel );
@@ -614,7 +692,7 @@ void SysTrayIcon::quickpostFromTemplate( int id, QString templateString, QString
       abortAction->setEnabled( true );
       httpBusy = true;
       templateQPActive = true;
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN32
       setIcon( QIcon( QPixmap( sysTrayIcon_busy_xpm ) ) );
 #endif
       connect( netmgr, SIGNAL( finished( QNetworkReply * ) ),
@@ -645,6 +723,48 @@ void SysTrayIcon::quickpostFromDBus( QString &url, QString &content )
   doQP( content );
 }
 
+void SysTrayIcon::chooseQuickpostTemplate()
+{
+#ifdef UNITY_LAUNCHER
+  QListWidgetItem *thisTemplate;
+
+  QDialog chooser;
+  Ui::ListDialogBase ldui;
+  ldui.setupUi( &chooser );
+
+  chooser.setAttribute( Qt::WA_DeleteOnClose, false );
+  chooser.setWindowTitle( tr( "Choose template" ) );
+  ldui.mainLabel->setText( tr( "Templates:" ) );
+
+  Q_FOREACH( QuickpostTemplate *temp, quickpostTemplateActions ) {
+    if( temp != 0 ) {
+      thisTemplate = new QListWidgetItem( temp->text() );
+      thisTemplate->setData( 32, temp->identifier() );
+      ldui.lwFileTemplateList->addItem( thisTemplate );
+    }
+  }
+
+  connect( ldui.lwFileTemplateList, SIGNAL( itemDoubleClicked( QListWidgetItem * ) ),
+           this, SLOT( actOnChooseQuickpostTemplate( QListWidgetItem * ) ) );
+  connect( ldui.lwFileTemplateList, SIGNAL( itemDoubleClicked( QListWidgetItem * ) ),
+           &chooser, SLOT( reject() ) );
+
+  if( chooser.exec() ) {
+    if( quickpostTemplateActions.at( ldui.lwFileTemplateList->currentRow() ) != 0 )
+      quickpostTemplateActions[ldui.lwFileTemplateList->currentRow()]->trigger();
+  }
+#endif
+}
+
+void SysTrayIcon::actOnChooseQuickpostTemplate( QListWidgetItem *item )
+{
+#ifdef UNITY_LAUNCHER
+  QuickpostTemplate *temp = quickpostTemplateActions.at( item->data( 32 ).toInt() );
+  if( temp )
+    temp->trigger();
+#endif
+}
+
 void SysTrayIcon::setNewWindowAtStartup( bool nwas )
 {
   QSettings settings;
@@ -676,7 +796,7 @@ void SysTrayIcon::handleDone( QNetworkReply *reply )
       default:
         errorString = tr( "Document was not received correctly." ); break;
     }
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
     QMessageBox::warning( 0, tr( "Quickpost Error" ),
                           errorString, QMessageBox::Cancel );
 #else
@@ -693,7 +813,7 @@ void SysTrayIcon::handleDone( QNetworkReply *reply )
   netmgr->disconnect();
   currentReply->deleteLater();
   currentReply = NULL;
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
   setIcon( QIcon( QPixmap( sysTrayIcon_xpm ) ) );
 #endif
 }
@@ -710,11 +830,6 @@ void SysTrayIcon::doQuit()
       edwins++;
   }
 
-#ifndef NO_DEBUG_OUTPUT
-  // qDebug() << edwins << " main windows";
-#endif
-
-  //if( QApplication::topLevelWidgets().size() <= noWidgets )
   if( !edwins )
     QCoreApplication::quit();
   else {
@@ -805,12 +920,12 @@ void SysTrayIcon::doQP( QString receivedText )
     }
   }
 
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
   //setNoStatusBar( c );
 #endif
   c->show();
   c->activateWindow();
-#ifdef Q_WS_WIN
+#ifdef Q_OS_WIN32
   setIcon( QIcon( QPixmap( sysTrayIcon_xpm ) ) );
 #endif
 
@@ -995,7 +1110,7 @@ void SysTrayIcon::configureQuickpostTemplates( QWidget *parent )
     templateDocument.insertBefore( templateDocument.createProcessingInstruction( "xml", "version=\"1.0\"" ),
                                    templateDocument.firstChild() );
     settings.beginGroup( "account" );
-#if defined Q_WS_WIN
+#if defined Q_OS_WIN32
     QString templateFileDir = QDir::toNativeSeparators( settings.value( "localStorageDirectory",
                                                                         QString( "%1/QTM blog" ).arg( QDir::homePath() ) ).toString() );
 #else
@@ -1014,7 +1129,7 @@ void SysTrayIcon::configureQuickpostTemplates( QWidget *parent )
       templateFile->close();
     }
     else
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
       QMessageBox::warning( 0, tr( "Error" ),
                             tr( "Could not write to templates file" ),
                             QMessageBox::Cancel );
