@@ -36,19 +36,24 @@
 #include <QStringList>
 #include <QDomElement>
 #include "Application.h"
+#ifdef UNITY_LAUNCHER
+#include "ui_ListDialogBase.h"
+#endif
+
 class QMenu;
 class QAction;
 class QHttpResponseHeader;
 class QuickpostTemplate;
+class QListWidgetItem;
 
 class QNetworkAccessManager;
 class QNetworkReply;
 
-#ifdef Q_WS_MAC
-extern void qt_mac_set_dock_menu( QMenu * );
-#define STI_SUPERCLASS QObject
+#ifdef Q_OS_MAC
+void qt_mac_set_dock_menu( QMenu * );
+//#define STI_SUPERCLASS QObject
 #else
-#define STI_SUPERCLASS QSystemTrayIcon
+//#define STI_SUPERCLASS QSystemTrayIcon
 #endif
 
 class SysTrayIcon : public STI_SUPERCLASS
@@ -70,7 +75,9 @@ public slots:
   void newDoc();
   void openRecentFile();
   void choose( QString fname = QString() );
+  void chooseRecentFile();
   void quickpost( QClipboard::Mode mode = QClipboard::Clipboard );
+  void chooseQuickpostTemplate();
   bool handleArguments();
   void doQuit();
   void saveAll();
@@ -82,6 +89,8 @@ private slots:
   void setNewWindowAtStartup( bool );
   void handleDone( QNetworkReply * );
   void abortQP();
+  void openRecentFileFromDialog( QListWidgetItem * );
+  void actOnChooseQuickpostTemplate( QListWidgetItem * );
 
 signals:
   void quickpostTemplateTitlesUpdated( QStringList );
