@@ -35,7 +35,7 @@
 
 #ifdef USE_SYSTRAYICON
 #include "SysTrayIcon.h"
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 #include "SuperMenu.h"
 //#include "macFunctions.h"
 #endif
@@ -55,10 +55,13 @@ int main( int argc, char *argv[] )
   if( QSystemTrayIcon::isSystemTrayAvailable() ) {
     sti = new SysTrayIcon;
     if( !sti->dontStart() ) {
-#ifndef Q_WS_MAC
+#ifndef Q_OS_MAC
       sti->show();
 #else
       SuperMenu *smenu = new SuperMenu( 0, sti );
+      smenu->setObjectName( "MacGlobalMenu" );
+      smenu->show();
+      smenu->handleNewWindowAtStartup();
 #endif
       app.setQuitOnLastWindowClosed( false );
     }
@@ -73,10 +76,11 @@ int main( int argc, char *argv[] )
       c->close();
   }
 #else
+  app.setupRecentFiles();
   c = new EditingWindow;
   c->setWindowTitle( QObject::tr( "QTM - new entry [*]" ) );
   if( c->handleArguments() ) {
-#if Q_WS_MAC
+#if Q_OS_MAC
     setNoStatusBar( c );
 #endif
     c->show();
