@@ -16,10 +16,10 @@ Icon=$1/share/icons/qtm-logo1.png
 # X-KDE-ServiceType=FooService
 EOF
 
-if [ $2 = "--unity" ]; then
+if [ "$2" = "--unity" ]; then
   cat <<EOF
 
-X-Ayatana-Desktop-Shortcuts=NewQTMDocument;OpenQTMDocument;QTMQuickpost;ReallyQuitQTM
+X-Ayatana-Desktop-Shortcuts=NewQTMDocument;OpenQTMDocument;OpenRecentQTMDocument;QTMQuickpost;QTMQuickpostFromTemplate;ReallyQuitQTM
 
 [NewQTMDocument Shortcut Group]
 Name=New Document
@@ -31,11 +31,21 @@ Name=Open
 Exec=qtm-choose
 TargetEnvironment=Unity
 
+[OpenRecentQTMDocument Shortcut Group]
+Name=Open recent file...
+Exec=qtm-chooseRecent
+TargetEnvironment=Unity
+
 [QTMQuickpost Shortcut Group]
 Name=Quickpost
 Exec=qtm-quickpost
 TargetEnvironment=Unity
 
+[QTMQuickpostFromTemplate Shortcut Group]
+Name=Quickpost from template
+Exec=qtm-chooseTemplate
+TargetEnvironment=Unity
+
 [ReallyQuitQTM Shortcut Group]
 Name=Really quit QTM
 Exec=qdbus uk.co.blogistan.catkin /MainApplication quit
